@@ -1,4 +1,4 @@
-# Copyright (C) 2008, 2009, 2010  Canonical, Ltd.
+# Copyright (C) 2008-2011  Canonical, Ltd.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,15 +23,15 @@ __all__ = [
 
 
 import os
-import gtk
-import sys
 import dbus
 import glib
-import pango
 import gobject
+import logging
 
 from operator import mod
 
+from gi.repository import Gtk, Pango
+
 from computerjanitorapp import __version__, setup_gettext
 from computerjanitorapp.gtk.dialogs import AreYouSure, CleanupProblem
 from computerjanitorapp.gtk.store import (
@@ -39,8 +39,12 @@ from computerjanitorapp.gtk.store import (
 from computerjanitorapp.utilities import format_size
 from computerjanitord.service import DBUS_INTERFACE_NAME
 
+
+Gtk.require_version('2.0')
+log = logging.getLogger('computerjanitor')
 _ = setup_gettext()
 
+
 GLADE = '/usr/share/computer-janitor/ComputerJanitor.ui'
 ROOT_WIDTH = 900
 ROOT_HEIGHT = 500
@@ -86,7 +90,7 @@ class UserInterface:
 
     def run(self):
         """Set up the widgets and run the main loop."""
-        builder = gtk.Builder()
+        builder = Gtk.Builder()
         builder.set_translation_domain('computerjanitor')
         # Load the glade ui file, which can be overridden from the environment
         # for testing purposes.
@@ -109,7 +113,7 @@ class UserInterface:
         root.set_default_size(ROOT_WIDTH, ROOT_HEIGHT)
         # Map the root window and go!
         root.show()
-        gtk.main()
+        Gtk.main()
 
     def find_and_bind_widgets(self, builder):
         """Bind widgets and callbacks."""
@@ -117,8 +121,8 @@ class UserInterface:
         # keeping track of them as mapped to their name.
         self.widgets = {}
         for ui_object in builder.get_objects():
-            if issubclass(type(ui_object), gtk.Buildable):
-                widget_name = gtk.Buildable.get_name(ui_object)
+            if issubclass(type(ui_object), Gtk.Buildable):
+                widget_name = Gtk.Buildable.get_name(ui_object)
                 self.widgets[widget_name] = ui_object
                 # Search through the attributes of this instance looking for
                 # callbacks for this widget.  We use the naming convention
@@ -143,29 +147,29 @@ class UserInterface:
         # Each TreeView contains two columns.  The leftmost one is a toggle
         # that when select tells c-j to act on that cruft.  Deselecting the
         # toggle ignores the package for next time.
-        toggle_cr = gtk.CellRendererToggle()
+        toggle_cr = Gtk.CellRendererToggle()
         toggle_cr.connect('toggled', self._toggled, treeview)
         toggle_cr.set_property('yalign', 0)
-        toggle_col = gtk.TreeViewColumn()
-        toggle_col.pack_start(toggle_cr)
+        toggle_col = Gtk.TreeViewColumn()
+        toggle_col.pack_start(toggle_cr, True)
         toggle_col.add_attribute(toggle_cr, 'active', ListStoreColumns.active)
         treeview.append_column(toggle_col)
         # The rightmost column contains the details of the cruft.  It will
         # always contain the cruft name and can be expanded to display cruft
         # details.  Tell the column to get its toggle's active state from the
         # model.
-        name_cr = gtk.CellRendererText()
+        name_cr = Gtk.CellRendererText()
         name_cr.set_property('yalign', 0)
-        name_cr.set_property('wrap-mode', pango.WRAP_WORD)
-        name_col = gtk.TreeViewColumn()
-        name_col.pack_start(name_cr)
+        name_cr.set_property('wrap-mode', Pango.WrapMode.WORD)
+        name_col = Gtk.TreeViewColumn()
+        name_col.pack_start(name_cr, True)
         name_col.add_attribute(name_cr, 'markup', ListStoreColumns.text)
         treeview.append_column(name_col)
         self.cruft_name_columns.add(name_col)
         # The individual crufts may or may not be visible in this TreeView.
         # It's the filter function that controls this, so set that now.
-        filter_store = self.store.filter_new()
-        filter_store.set_visible_func(filter_func)
+        filter_store = self.store.filter_new(None)
+        filter_store.set_visible_func(filter_func, None)
         treeview.set_model(filter_store)
         # Each TreeView has a popup menu for select or deselecting all visible
         # cruft.
@@ -176,12 +180,12 @@ class UserInterface:
 
         :param treeview: The `TreeView` to attach the menu to.
         """
-        select_all = gtk.MenuItem(label='Select all')
+        select_all = Gtk.MenuItem(label='Select all')
         select_all.connect('activate', self.popup_menu_select_all, treeview)
-        unselect_all = gtk.MenuItem(label='Unselect all')
+        unselect_all = Gtk.MenuItem(label='Unselect all')
         unselect_all.connect('activate',
                              self.popup_menu_unselect_all, treeview)
-        menu = gtk.Menu()
+        menu = Gtk.Menu()
         menu.append(select_all)
         menu.append(unselect_all)
         menu.show_all()
@@ -290,7 +294,7 @@ class UserInterface:
 
     # Popup menu support.
 
-    def popup_menu_foreach_set_state(self, treeview, enabled):
+    def _treeview_foreach_set_set_state(self, treeview, enabled):
         """Set the state of the cruft 'active' flag for all cruft.
 
         :param treeview: The `TreeView` to set cruft state on.
@@ -314,10 +318,10 @@ class UserInterface:
         self.janitord.save()
 
     def popup_menu_select_all(self, menuitem, treeview):
-        self.popup_menu_foreach_set_state(treeview, True)
+        self._treeview_foreach_set_set_state(treeview, True)
 
     def popup_menu_unselect_all(self, menuitem, treeview):
-        self.popup_menu_foreach_set_state(treeview, False)
+        self._treeview_foreach_set_set_state(treeview, False)
 
     # Progress bar
 
@@ -389,7 +393,7 @@ class UserInterface:
         # Don't quit while we're working.
         if self.working:
             return True
-        gtk.main_quit()
+        Gtk.main_quit()
 
     on_window_delete_event = on_quit_menuitem_activate
 
@@ -402,7 +406,7 @@ class UserInterface:
         """
         # Original comment: This is slightly tricky and probably a source of
         # bugs.  Oh well.
-        if event.button == 1:
+        if event.button.button == 1:
             # Left button event.  Select the row being clicked on.  If the
             # click is on the cruft name, show or hide its long description.
             # If the click the click is elsewhere do not handle it.  This
@@ -423,7 +427,7 @@ class UserInterface:
                 # We are not handling this event so that the toggle button
                 # handling can occur.
                 return False
-        elif event.button == 3:
+        elif event.button.button == 3:
             # Right button event.  Pop up the select/deselect all menu.
             treeview.grab_focus()
             x = int(event.x)
@@ -434,7 +438,14 @@ class UserInterface:
                 path, column, cell_x, cell_y = pathinfo
                 treeview.set_cursor(path, column, False)
             menu = self.popup_menus[treeview]
-            menu.popup(None, None, None, event.button, time)
+            try:
+                menu.popup_for_device(None, None, None, None, None,
+                        event.button.button, time)
+            except AttributeError:
+                # popup_for_device() is introspection safe, but only exists in
+                # GTK3. popup() isn't introspectable, so in GTK 2 we need to
+                # disable the popup menu functionality
+                log.warning('popup menu not supported when using GTK2')
             return True
         else:
             # No other events are handled by us.
@@ -454,7 +465,7 @@ class UserInterface:
         # Get the rightmost of the two columns in the TreeView, i.e. the one
         # containing the text.
         column = treeview.get_column(1)
-        name_cr = column.get_cell_renderers()[0]
+        name_cr = column.get_cells()[0]
         # Wrap to the entire width of the column.
         width = column.get_width()
         name_cr.set_property('wrap-width', width)
@@ -488,13 +499,56 @@ class UserInterface:
         show_ignored_cruft = menuitem.get_active()
         iter = self.store.get_iter_first()
         while iter:
-            cruft_name = self.store.get_value(iter, ListStoreColumns.name)
             server_ignored = self.store.get_value(
                 iter, ListStoreColumns.server_ignored)
             show = (show_ignored_cruft or not server_ignored)
             self.store.set_value(iter, ListStoreColumns.show, show)
             iter = self.store.iter_next(iter)
 
+    def _edit_menuitem_set_select_state(self, enabled, *treeviews):
+        """Set the specified state on the selected treeviews.
+
+        :param enabled: The new state flag for all cruft.  True means enabled.
+        :type enabled: bool
+        :param treeviews: Sequence of `TreeView` object to set cruft state on.
+        """
+        for treeview in treeviews:
+            self._treeview_foreach_set_set_state(treeview, enabled)
+
+    def on_select_all_cruft_activate(self, menuitem):
+        """Select all cruft, both package and other."""
+        self._edit_menuitem_set_select_state(
+            True,
+            self.widgets['unused_treeview'],
+            self.widgets['optimize_treeview'])
+
+    def on_select_all_packages_activate(self, menuitem):
+        """Select all cruft, both package and other."""
+        self._edit_menuitem_set_select_state(
+            True, self.widgets['unused_treeview'])
+
+    def on_select_all_other_activate(self, menuitem):
+        """Select all cruft, both package and other."""
+        self._edit_menuitem_set_select_state(
+            True, self.widgets['optimize_treeview'])
+
+    def on_deselect_all_cruft_activate(self, menuitem):
+        """Select all cruft, both package and other."""
+        self._edit_menuitem_set_select_state(
+            False,
+            self.widgets['unused_treeview'],
+            self.widgets['optimize_treeview'])
+
+    def on_deselect_all_packages_activate(self, menuitem):
+        """Select all cruft, both package and other."""
+        self._edit_menuitem_set_select_state(
+            False, self.widgets['unused_treeview'])
+
+    def on_deselect_all_other_activate(self, menuitem):
+        """Select all cruft, both package and other."""
+        self._edit_menuitem_set_select_state(
+            False, self.widgets['optimize_treeview'])
+
     def on_do_button_clicked(self, *args):
         """JFDI, well almost."""
         self.count = 0
@@ -518,7 +572,10 @@ class UserInterface:
             # it's very helpful to display the low-level apt exception in a
             # dialog.  `exception` will always be a DBusException; we won't
             # get the more useful PackageCleanupError.
-            print >> sys.stderr, exception
+            #
+            # We use log.error() instead of log.exception() because we're not
+            # in an exception handler.
+            log.error('%s', exception)
             CleanupProblem(self).run()
             self.working = False
         def reply():
