@@ -1,5 +1,6 @@
 # add_nfs_common_plugin.py - install nfs-common if nfs is used
-# Copyright (C) 2009  Canonical, Ltd.
+#
+# Copyright (C) 2009-2011  Canonical, Ltd.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,10 +15,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
-import grp
 import logging
-import os
-import subprocess
 
 import computerjanitor
 import computerjanitorapp
@@ -27,10 +25,10 @@ _ = computerjanitorapp.setup_gettext()
 class AddNfsCommonPlugin(computerjanitor.Plugin):
 
     """Plugin to install missing nfs-common package, if nfs is being used.
-    
+
     This is a fix for the feisty->gutsy transition of utils-linux to
     nfs-common. See also LP: #141559.
-    
+
     """
 
     description = _("NFS is being used, so the nfs-common package needs "
