@@ -1,5 +1,6 @@
 # landscape_stub_plugin.py
-# Copyright (C) 2009  Canonical, Ltd.
+#
+# Copyright (C) 2009-2011  Canonical, Ltd.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,8 +15,6 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
-import os
-
 import computerjanitor
 import computerjanitorapp
 _ = computerjanitorapp.setup_gettext()
@@ -25,14 +24,17 @@ class LandscapePackageCruft(computerjanitor.PackageCruft):
     def __init__(self, app, pkg, description):
         computerjanitor.PackageCruft.__init__(self, pkg, description)
         self.app = app
-    
+
     def cleanup(self):
-        self.app.apt_cache.markRemove(self._pkg.name, 
-                                  "custom landscape stub removal rule")
+        self.app.apt_cache.markRemove(self._pkg.name,
+                                      "custom landscape stub removal rule")
         if self.app.apt_cache.has_key("landscape-common"):
             self.app.apt_cache["landscape-common"].markKeep()
-            self.app.apt_cache.markInstall("landscape-common", 
-                                       "custom landscape-common stub install rule (to ensure its nor marked for auto-remove)")
+            self.app.apt_cache.markInstall(
+                "landscape-common",
+                "custom landscape-common stub install rule "
+                "(to ensure its nor marked for auto-remove)")
+
 
 class LandscapeStubPlugin(computerjanitor.Plugin):
 
